==> gtkmm-1.3.11.tar.bz2: gtkmm-1.3.11/gtk/gtkmm/accelkey.cc <==
// -*- c++ -*-
/* $Id: accelkey.cc,v 1.4 2002/04/02 13:24:46 daniel Exp $ */

/* 
 *
 * Copyright 1998-1999 The Gtk-- Development Team
 * Copyright 2001      Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/accelkey.h>
#include <gtkmm/accelgroup.h>

namespace Gtk
{

namespace Menu_Helpers
{

AccelKey::AccelKey()
: key_(GDK_VoidSymbol),
  mod_((Gdk::ModifierType)0)
{
}

AccelKey::AccelKey(Gdk::ModifierType accel_mods, guint accel_key,
                   const Glib::ustring& accel_path)
: key_(accel_key),
  mod_(accel_mods),
  path_(accel_path)
{
}

AccelKey::AccelKey(const Glib::ustring& str,
                   const Glib::ustring& accel_path)
: path_(accel_path)
{
  AccelGroup::parse (str, key_, mod_);
}

AccelKey::AccelKey(const AccelKey& src)
{
  key_ = src.key_;
  mod_ = src.mod_;
  path_ = src.path_;
}

AccelKey& AccelKey::operator=(const AccelKey& src)
{
  key_ = src.key_;
  mod_ = src.mod_;
  path_ = src.path_;

  return *this;
}

guint AccelKey::get_key() const
{
  return key_;
}

Gdk::ModifierType AccelKey::get_mod() const
{
  return mod_;
}

Glib::ustring AccelKey::get_path() const
{
  return path_;
}

bool AccelKey::is_null() const
{
  return ( (key_ == GDK_VoidSymbol) || !(get_key() > 0) ); //both seem to be invalid.
}

Glib::ustring AccelKey::get_abbrev() const
{
  return AccelGroup::name (key_, mod_);
}

} /* namespace Menu_Helpers */

} /* namespace Gtk */

==> gtkmm-1.3.18.tar.bz2: gtkmm-1.3.18/gtk/gtkmm/accelkey.cc <==
// -*- c++ -*-
/* $Id: accelkey.cc,v 1.5 2002/07/13 15:58:35 murrayc Exp $ */

/* 
 *
 * Copyright 1998-1999 The Gtk-- Development Team
 * Copyright 2001      Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/accelkey.h>
#include <gtkmm/accelgroup.h>

namespace Gtk
{

namespace Menu_Helpers
{

AccelKey::AccelKey()
: key_(GDK_VoidSymbol),
  mod_((Gdk::ModifierType)0)
{
}

AccelKey::AccelKey(Gdk::ModifierType accel_mods, guint accel_key,
                   const Glib::ustring& accel_path)
: key_(accel_key),
  mod_(accel_mods),
  path_(accel_path)
{
}

AccelKey::AccelKey(const Glib::ustring& accelerator, const Glib::ustring& accel_path)
: path_(accel_path)
{
  //Get the key and mod by parsing the accelerator string:
  AccelGroup::parse (accelerator, key_, mod_);
}

AccelKey::AccelKey(const AccelKey& src)
{
  key_ = src.key_;
  mod_ = src.mod_;
  path_ = src.path_;
}

AccelKey& AccelKey::operator=(const AccelKey& src)
{
  key_ = src.key_;
  mod_ = src.mod_;
  path_ = src.path_;

  return *this;
}

guint AccelKey::get_key() const
{
  return key_;
}

Gdk::ModifierType AccelKey::get_mod() const
{
  return mod_;
}

Glib::ustring AccelKey::get_path() const
{
  return path_;
}

bool AccelKey::is_null() const
{
  return ( (key_ == GDK_VoidSymbol) || !(get_key() > 0) ); //both seem to be invalid.
}

Glib::ustring AccelKey::get_abbrev() const
{
  return AccelGroup::name (key_, mod_);
}

} /* namespace Menu_Helpers */

} /* namespace Gtk */
